@@ -308,13 +308,14 @@ def get_all_changesets_rest_api():
 
 
 def execute(commandLine):
-    commandLine = commandLine + login_details
     logging.debug("CMD: '{}'".format(commandLine))
     process = Popen(commandLine, shell=True, stdout=PIPE, stderr=PIPE)
     out = process.stdout.read().decode('utf-8', errors='ignore').strip()
+    out = out.replace("\r", "")
     out = str.join("", list([x for x in out if x in string.printable]))
     logging.debug("CMD: '{}' RESULT: {}".format(commandLine, out))
     error = process.stderr.read().decode('utf-8', errors='ignore').strip()
+    error = error.replace("\r", "")
     error = str.join("", list([x for x in error if x in string.printable]))
     if error and not out:
         process.kill()
@@ -357,8 +358,6 @@ def get_last_branch_changeSet(branch, numberOfChangets):
     output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
         "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
 
-    logging.debug("OUTPUT REPR: {}".format(repr(output)))
-
     changeSetList = []
 
     output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
