@@ -1,8 +1,27 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 from functools import reduce
+import warnings
+import os
+import sys
+import json
+import string
+import logging
+import logging.handlers as handlers
+from datetime import datetime
+from functools import reduce
+from subprocess import Popen, PIPE
+try:
+    import requests
+    from requests.adapters import HTTPAdapter
+    from requests.sessions import Session
+    from requests.adapters import Retry
+except ImportError:
+    warnings.warn("Please install 'requests'. 'pip install requests'")
+    sys.exit(1)
+
+import re
 
-output = open('./mock-output.txt', 'r').read()
 
 
 import re
@@ -33,21 +52,33 @@ def to_iso(data):
     else:
         return data
 
+def execute(commandLine):
+    logging.debug("CMD: '{}'".format(commandLine))
+    process = Popen(commandLine, shell=True, stdout=PIPE, stderr=PIPE)
+    out = process.stdout.read().decode('utf-8', errors='ignore').strip()
+    out = out.replace("\r", "")
+    out = str.join("", list([x for x in out if x in string.printable]))
+    logging.debug("CMD: '{}' RESULT: {}".format(commandLine, out))
+    error = process.stderr.read().decode('utf-8', errors='ignore').strip()
+    error = error.replace("\r", "")
+    error = str.join("", list([x for x in error if x in string.printable]))
+    if error and not out:
+        process.kill()
+        logging.error("CMD: '{}' IF ERR OUT {}".format(commandLine, out))
+        logging.error("CMD: '{}' {}".format(commandLine, error))
+        raise Exception(error)
+    return out
+
 def get_last_branch_changeSet(branch, numberOfChangets):
     # output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
     #     "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
+    commandLine = "cat ./mock-output-lf.txt"
+    output = execute(commandLine)
 
     changeSetList = []
-    # changeSetDict = {}
-    # propertyName = ""
-    # propertyData = ""
-    # needPropertData = False
-    # itemsDict = {}
-    # isItemDict = False
-    # changeSetDict["branch"] = branch
-    out = str.join("", list([x for x in output if x in string.printable]))
 
-    output_list = [item for item in out.split("-" * 79 + '\n\n') if item]
+    # output = output.replace("\r", "")
+    output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
 
     idx = 0
 
